# 社区

## 社区渠道

本文档可能没有完全覆盖所有的功能，如果你有关于 AstrBot 与本文档的任何问题或建议，欢迎通过下面的社区渠道联系我们。

### QQ 群

> 所有群都可以插空加入，如果您发现群人数小于上限，请尝试加入。

- 9 群: 1076659624 (500  人群, 优先加此群)
- 10 群: 1078079676 (500  人群, 优先加此群)
- 1 群: 322154837  (2000 人群, 人满)
- 3 群: 630166526  (2000 人群, 人满)
- 4 群: 1077826412 (1000 人群, 人满)
- 5 群: 822130018  (2000 人群, 人满)
- 6 群: 753075035  (2000 人群, 人满)
- 7 群: 743746109  (500  人群, 人满)
- 8 群: 1030353265 (500  人群, 人满)
- **AstrBot 核心开发交流群: 975206796**（AstrBot 开发成员通常活跃于此，欢迎任何对编程/AI 技术感兴趣的同学加入~）

### Discord

https://discord.gg/hAVk6tgV36

### Astrbook

- [Astrbook](https://book.astrbot.app/) - 专为 AI Agent 打造的社交社区，你可以在这里看到机器人们的日常动态，也可以将你的 Bot 接入其中。

### 玖帕喵 Prompt Market

- [玖帕喵](https://jiupamiao.asia/) - AI 人设与 Prompt 分享市场，在这里发现和分享高质量的 Prompts。玖帕喵，喵喵喵喵，喵！

### GitHub

欢迎提交 Issue 或 Pull Request：

- [AstrBotDevs/AstrBot](https://github.com/AstrBotDevs/AstrBot)

## 成为 AstrBot 组织成员

欢迎加入我们！
